slepc-3.18.0 2022-10-01
Report Typos and Errors

# PEPSetFromOptions

Sets PEP options from the options database. This routine must be called before PEPSetUp() if the user is to be allowed to set the solver type.

### Synopsis

    #include "slepcpep.h"
    PetscErrorCode PEPSetFromOptions(PEP pep)

Collective on pep

### Input Parameters

| pep | - the polynomial eigensolver context

### Notes

To see all options, run your program with the -help option.

### See Also

PEPSetOptionsPrefix()

### Level

beginner

### Location

src/pep/interface/pepopts.c

### Examples

src/pep/tutorials/ex16.c.html
src/pep/tutorials/ex16f90.F90.html
src/pep/tutorials/ex17.c.html
src/pep/tutorials/ex28.c.html
src/pep/tutorials/ex38.c.html
src/pep/tutorials/ex40.c.html
src/pep/tutorials/ex50.c.html
src/pep/tutorials/nlevp/acoustic_wave_1d.c.html
src/pep/tutorials/nlevp/acoustic_wave_2d.c.html
src/pep/tutorials/nlevp/butterfly.c.html
src/pep/tutorials/nlevp/damped_beam.c.html
Index of all PEP routines
Table of Contents for all manual pages
Index of all manual pages